
import React from 'react';
import { Button } from '@/components/ui/button';
import { useTheme } from '../contexts/ThemeContext';
import { FiMenu, FiX, FiHelpCircle, FiUsers, FiDollarSign, FiZap, FiExternalLink } from 'react-icons/fi';

interface LeftSidebarProps {
  onPromptSelect: (prompt: string, content: any) => void;
}

const suggestedQuestions = [
  { text: "What is MCP?", icon: FiHelpCircle },
  { text: "Who is this for?", icon: FiUsers },
  { text: "Show me how I can earn", icon: FiDollarSign },
  { text: "What can you help me with?", icon: FiZap },
];

const LeftSidebar: React.FC<LeftSidebarProps> = ({ onPromptSelect }) => {
  const { sidebarOpen, setSidebarOpen } = useTheme();

  const handlePromptClick = (prompt: string) => {
    // This will trigger the same logic as in ChatInterface
    onPromptSelect(prompt, null);
  };

  return (
    <>
      {/* Toggle Button */}
      {!sidebarOpen && (
        <Button
          variant="ghost"
          onClick={() => setSidebarOpen(true)}
          className="fixed top-24 left-4 z-50 w-10 h-10 rounded-xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-md bg-white/80 dark:bg-black/80 hover:bg-white/90 dark:hover:bg-black/90 transition-all duration-300 shadow-lg"
        >
          <FiMenu className="w-4 h-4" />
        </Button>
      )}

      {/* Sidebar */}
      <div
        className={`fixed left-0 top-20 h-[calc(100vh-80px)] w-72 transform transition-transform duration-500 ease-in-out z-40 ${
          sidebarOpen ? 'translate-x-0' : '-translate-x-full'
        }`}
      >
        <div className="h-full border-r border-gray-200/10 dark:border-gray-700/10 backdrop-blur-xl bg-white/90 dark:bg-black/90">
          <div className="p-6 h-full flex flex-col">
            {/* Header */}
            <div className="flex items-center justify-between mb-8">
              <h2 className="text-lg font-medium text-gray-900 dark:text-white">
                Quick Start
              </h2>
              <Button
                variant="ghost"
                onClick={() => setSidebarOpen(false)}
                className="w-8 h-8 rounded-lg hover:bg-gray-100 dark:hover:bg-gray-800 transition-colors"
              >
                <FiX className="w-4 h-4" />
              </Button>
            </div>

            {/* Suggested Questions */}
            <div className="flex-1 space-y-6">
              <div>
                <h3 className="text-xs font-medium text-gray-500 dark:text-gray-400 uppercase tracking-wider mb-4">
                  Explore Features
                </h3>
                <div className="space-y-2">
                  {suggestedQuestions.map((question, index) => (
                    <Button
                      key={index}
                      variant="ghost"
                      onClick={() => handlePromptClick(question.text)}
                      className="w-full justify-start p-4 h-auto text-left rounded-xl border-0 bg-transparent hover:bg-gray-50 dark:hover:bg-gray-800/50 transition-all duration-200 group"
                    >
                      <question.icon className="w-4 h-4 mr-3 text-gray-400 group-hover:text-gray-600 dark:group-hover:text-gray-300 transition-colors" />
                      <span className="text-sm text-gray-700 dark:text-gray-300 group-hover:text-gray-900 dark:group-hover:text-white transition-colors">
                        {question.text}
                      </span>
                    </Button>
                  ))}
                </div>
              </div>

              {/* Website Link */}
              <div className="pt-6 border-t border-gray-200/20 dark:border-gray-700/20">
                <h3 className="text-xs font-medium text-gray-500 dark:text-gray-400 uppercase tracking-wider mb-4">
                  Resources
                </h3>
                <Button
                  variant="ghost"
                  asChild
                  className="w-full justify-start p-4 h-auto text-left rounded-xl border-0 bg-transparent hover:bg-gray-50 dark:hover:bg-gray-800/50 transition-all duration-200 group"
                >
                  <a href="https://yourdomain.com" target="_blank" rel="noopener noreferrer">
                    <FiExternalLink className="w-4 h-4 mr-3 text-gray-400 group-hover:text-gray-600 dark:group-hover:text-gray-300 transition-colors" />
                    <span className="text-sm text-gray-700 dark:text-gray-300 group-hover:text-gray-900 dark:group-hover:text-white transition-colors">
                      Visit Website
                    </span>
                  </a>
                </Button>
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};

export default LeftSidebar;
